pub fn vec_delay_read(buf: &[f32], pos: usize, dst: &mut [f32], time: &[f32])Expand description
Per-sample modulated delay read with linear interpolation.
For each sample i, reads from circular buffer at a fractional offset
time[i] samples behind where the write head was at sample i.
pos should be the write head position after the most recent vec_ring_write.